@@ -11,7 +11,7 @@ use constant DEBUG        => $ENV{MOJO_IRC_DEBUG}     || 0;
 use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE__), 'mojo-irc-client.crt';
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 our %NUMERIC2NAME = (470 => 'ERR_LINKCHANNEL');
 
@@ -19,7 +19,7 @@ my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
 my @DEFAULT_EVENTS = qw(
   irc_ping irc_nick irc_notice irc_rpl_welcome err_nicknameinuse
-  ctcp_ping ctcp_time ctcp_version
+  irc_rpl_isupport ctcp_ping ctcp_time ctcp_version
 );
 
 has connect_timeout => sub { $ENV{MOJO_IRC_CONNECT_TIMEOUT} || 30 };
@@ -30,6 +30,11 @@ has nick   => sub { shift->_build_nick };
 has parser => sub { Parse::IRC->new; };
 has pass   => '';
 has real_host => '';
+
+has server_settings => sub {
+  return {chantypes => '#', prefix => '(ov)@+'};
+};
+
 has track_any => 0;
 has tls       => undef;
 has user      => sub { $ENV{USER} || getlogin || getpwuid($<) || 'anonymous' };
@@ -167,11 +172,11 @@ sub disconnect {
 sub register_default_event_handlers {
   my $self = shift;
 
-  Scalar::Util::weaken($self);
   for my $event (@DEFAULT_EVENTS) {
-    next if $self->has_subscribers($event);
-    $self->on($event => $self->can($event));
+    $self->on($event => $self->can($event)) unless $self->has_subscribers($event);
   }
+
+  return $self;
 }
 
 sub write {
@@ -238,6 +243,20 @@ sub irc_ping {
   $self->write(PONG => $message->{params}[0]);
 }
 
+sub irc_rpl_isupport {
+  my ($self, $message) = @_;
+  my $params          = $message->{params};
+  my $server_settings = $self->server_settings;
+  my %got;
+
+  for my $i (1 .. @$params - 1) {
+    next unless $params->[$i] =~ /([A-Z]+)=?(\S*)/;
+    my ($k, $v) = (lc $1, $2);
+    $got{$k} = 1;
+    $server_settings->{$k} = $v || 1;
+  }
+}
+
 sub irc_rpl_welcome {
   my ($self, $message) = @_;
   $self->nick($message->{params}[0]);
@@ -317,7 +336,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.41
+0.42
 
 =head1 SYNOPSIS
 
@@ -457,6 +476,17 @@ server that we are connected to.
 Server name and, optionally, a port to connect to. Changing this while
 connected to the IRC server will issue a reconnect.
 
+=head2 server_settings
+
+  $hash = $self->server_settings;
+
+Holds information about the server. See
+L<https://github.com/jhthorsen/mojo-irc/blob/master/t/ua-channel-users.t> for
+example data structure.
+
+Note that this attribute is EXPERIMENTAL and the structure of the values it
+holds.
+
 =head2 user
 
 IRC username. Defaults to current logged in user or falls back to "anonymous".
@@ -574,6 +604,10 @@ broken...QUOTE PASS...".
 
 Responds to the server with "PONG ...".
 
+=head2 irc_rpl_isupport
+
+Used to populate L</server_settings> with information about the server.
+
 =head2 irc_rpl_welcome
 
 Used to get the hostname of the server. Will also set up automatic PING
